module("ui.List")
.require("ui.Core", "ui.ItemRenderer")
.declare("ui.List").extend("ui.MVCComponent")
.as({
    widgetName:"list",

    styles:["%basePath%/resources/styles/ui-list.css"],
    
    options: {
        itemRenderer:"ui.ItemRenderer",
        itemRendererOptions:{},
        view:"%basePath%/resources/views/ListView.html",
        emptyMessage:"No items...",
        itemWrapperSelector:".ui-list-item"
    },

    converters:{
        "itemRenderer":"string module"
    },

    events:["itemClick","itemSelected", "itemChanged", "itemRendered"],

    _init: function(){
        this.base();
        if(this.options.datasource){
            this.datasource(this.options.datasource);
        }
    },

    _itemMouseOver: function (e){
        jQuery(e.currentTarget).closest(this.options.itemWrapperSelector).addClass("hover");
    },

    _itemMouseOut: function (e){
        jQuery(e.currentTarget).closest(this.options.itemWrapperSelector).removeClass("hover");
    },

    _itemClick: function (e){
        this.setSelectedItem(e.currentTarget.__itemData);
        this.trigger({
            type:"itemClick",
            item:e.currentTarget
        })
    },

    _itemRender:function(){
        this.trigger({type:"itemRendered"});
    },

    updateDisplay: function(){
        jQuery.extend(this.viewData, {itemCount : this._datasource && this._datasource.length});
        this.base();
        
        var self = this;
        var items = jQuery("item",this.element);
        var itemRenderer = this.options.itemRenderer;
        var irOptions = this.options.itemRendererOptions;
        this._itemDataMap = [];

        if(jQuery.isArray(this._datasource) && itemRenderer){

            jQuery.each(this._datasource, function(idx, data){
                var itemPlaceholder = jQuery(items[idx]);

                if(itemPlaceholder){
                    var itemElement = jQuery("<div></div>");
                    var attrs = itemPlaceholder.getAttributes();
                    itemElement.attr(attrs);
                    itemPlaceholder.replaceWith(itemElement);
                    itemElement[0].__itemData = data;
                    
                    var target = new itemRenderer(irOptions,itemElement);

                    target.bind("mouseover",jQuery.proxy(self,"_itemMouseOver"));
                    target.bind("mouseout", jQuery.proxy(self,"_itemMouseOut"));
                    target.bind("click", jQuery.proxy(self,"_itemClick"));
                    target.bind("displayUpdated", jQuery.proxy(self,"_itemRender"));


                    target.bind("initialized", function(){
                        target.setData(data);
                    });

                    self._itemDataMap.push({
                        item:target.element[0],
                        data:data
                    });
                }
            })
        }
    },
    
    setSelectedItem: function(item){
        var itemElement = this._itemFromData(item)
        if(itemElement) {
            if(this._selectedItem !== item){

                jQuery(".selected", this.element).removeClass("selected");
                jQuery(itemElement).closest(this.options.itemWrapperSelector).addClass("selected");

                this._selectedItem = item;
                this.trigger({
                    type:"itemChanged",
                    item:itemElement,
                    itemData:item
                });

            }
            this.trigger({
                type:"itemSelected",
                item:itemElement,
                itemData:item
            });
        }
        else {
            throw new Error("Item must belong to datasource.")
        }
    },

    setSelectedItemFromData: function(data){
        if(data){
            this.setSelectedItem(data);
        }
    },

    setSelectedItemFromIndex: function(index){
        if(jQuery.isArray(this._datasource)){
            var data = this._datasource[index];
            this.setSelectedItemFromData(data);
        }
    },

    selectedItem:function(){
        return this._selectedItem;
    },

    selectedItemData:function(){
        return this.selectedItem();
    },

    selectedItemIndex:function(){
        if(jQuery.isArray(this._datasource)){
            var selectedItemData = this.selectedItemData();
            return this._datasource.indexOf(selectedItemData);
        }
        else return -1;
    },

    _itemFromData: function (data){
        var self = this;
        var selectedItem;
        if(data){
            jQuery.each(self._itemDataMap, function (idx, map){
                if(map["data"] === data){
                    selectedItem = map["item"];
                    return false;
                }
                else return true;
            })
        }

        if(selectedItem) {
            return selectedItem
        }
        else return null;
    },

    datasource: function(datasource){
        if(datasource){
            this._selectedItem = null;
            this._itemDataMap = [];
            this._datasource = datasource;
            this.updateDisplay();
        }

        return this._datasource;
    }
});
// SIG // Begin signature block
// SIG // MIIMzQYJKoZIhvcNAQcCoIIMvjCCDLoCAQExDjAMBggq
// SIG // hkiG9w0CBQUAMGYGCisGAQQBgjcCAQSgWDBWMDIGCisG
// SIG // AQQBgjcCAR4wJAIBAQQQEODJBs441BGiowAQS9NQkAIB
// SIG // AAIBAAIBAAIBAAIBADAgMAwGCCqGSIb3DQIFBQAEEKzc
// SIG // Don/pZRXVhychXyUR0egggoPMIIE/DCCBGWgAwIBAgIQ
// SIG // ZVIm4bIuGOFZDymFrCLnXDANBgkqhkiG9w0BAQUFADBf
// SIG // MQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24s
// SIG // IEluYy4xNzA1BgNVBAsTLkNsYXNzIDMgUHVibGljIFBy
// SIG // aW1hcnkgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkwHhcN
// SIG // MDkwNTIxMDAwMDAwWhcNMTkwNTIwMjM1OTU5WjCBtjEL
// SIG // MAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJ
// SIG // bmMuMR8wHQYDVQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3
// SIG // b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2UgYXQgaHR0
// SIG // cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykwOTEw
// SIG // MC4GA1UEAxMnVmVyaVNpZ24gQ2xhc3MgMyBDb2RlIFNp
// SIG // Z25pbmcgMjAwOS0yIENBMIIBIjANBgkqhkiG9w0BAQEF
// SIG // AAOCAQ8AMIIBCgKCAQEAvmcdtGCqEElvVhd8Zslehg3V
// SIG // 8ayncYOOi4n4iASJFQa6LYQhleTRnFBM+9IivdrysjU7
// SIG // Ho/DCfv8Ey5av4l8PTslHvbzWHuc9AG1xgq4gM6+J3Rh
// SIG // ZydNauXsgWFYeaPgFxASFSew4U00fytHIES53mYkZorN
// SIG // T7ofxTjIVJDhcvYZZnVquUlozzh5DaowqNssYEie16oU
// SIG // AamD1ziRMDkTlgM6fEBUtq3gLxuD3KgRUj4Cs9cr/SG2
// SIG // p1yjDwupphBQDjQuTafOyV4l1Iy88258KbwBXfwxh1rV
// SIG // jIVnWIgZoL818OoroyHnkPaD5ajtYHhee2CD/VcLXUEN
// SIG // Y1Rg1kMh7wIDAQABo4IB2zCCAdcwEgYDVR0TAQH/BAgw
// SIG // BgEB/wIBADBwBgNVHSAEaTBnMGUGC2CGSAGG+EUBBxcD
// SIG // MFYwKAYIKwYBBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlz
// SIG // aWduLmNvbS9jcHMwKgYIKwYBBQUHAgIwHhocaHR0cHM6
// SIG // Ly93d3cudmVyaXNpZ24uY29tL3JwYTAOBgNVHQ8BAf8E
// SIG // BAMCAQYwbQYIKwYBBQUHAQwEYTBfoV2gWzBZMFcwVRYJ
// SIG // aW1hZ2UvZ2lmMCEwHzAHBgUrDgMCGgQUj+XTGoasjY5r
// SIG // w8+AatRIGCx7GS4wJRYjaHR0cDovL2xvZ28udmVyaXNp
// SIG // Z24uY29tL3ZzbG9nby5naWYwHQYDVR0lBBYwFAYIKwYB
// SIG // BQUHAwIGCCsGAQUFBwMDMDQGCCsGAQUFBwEBBCgwJjAk
// SIG // BggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24u
// SIG // Y29tMDEGA1UdHwQqMCgwJqAkoCKGIGh0dHA6Ly9jcmwu
// SIG // dmVyaXNpZ24uY29tL3BjYTMuY3JsMCkGA1UdEQQiMCCk
// SIG // HjAcMRowGAYDVQQDExFDbGFzczNDQTIwNDgtMS01NTAd
// SIG // BgNVHQ4EFgQUl9BrqCZwyKE/lB8ILcQ1m6ShHvIwDQYJ
// SIG // KoZIhvcNAQEFBQADgYEAiwPA3ZTYQaJhabAVqHjHMMaQ
// SIG // PH5C9yS25INzFwR/BBCcoeL6gS/rwMpE53LgULZVECCD
// SIG // bpaS5JpRarQ3MdylLeuMAMcdT+dNMrqF+E6++mdVZfBq
// SIG // vnrKZDgaEBB4RXYx84Z6Aw9gwrNdnfaLZnaCG1nhg+W9
// SIG // SaU4VuXeQXcOWA8wggULMIID86ADAgECAhAjTaBL0kKF
// SIG // PErLmuhhwhm7MA0GCSqGSIb3DQEBBQUAMIG2MQswCQYD
// SIG // VQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4x
// SIG // HzAdBgNVBAsTFlZlcmlTaWduIFRydXN0IE5ldHdvcmsx
// SIG // OzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBhdCBodHRwczov
// SIG // L3d3dy52ZXJpc2lnbi5jb20vcnBhIChjKTA5MTAwLgYD
// SIG // VQQDEydWZXJpU2lnbiBDbGFzcyAzIENvZGUgU2lnbmlu
// SIG // ZyAyMDA5LTIgQ0EwHhcNMDkwODI3MDAwMDAwWhcNMTIw
// SIG // OTIwMjM1OTU5WjCByDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCkNhbGlmb3JuaWExEzARBgNVBAcTClNhbiBSYWZh
// SIG // ZWwxFjAUBgNVBAoUDUF1dG9kZXNrLCBJbmMxPjA8BgNV
// SIG // BAsTNURpZ2l0YWwgSUQgQ2xhc3MgMyAtIE1pY3Jvc29m
// SIG // dCBTb2Z0d2FyZSBWYWxpZGF0aW9uIHYyMR8wHQYDVQQL
// SIG // FBZEZXNpZ24gU29sdXRpb25zIEdyb3VwMRYwFAYDVQQD
// SIG // FA1BdXRvZGVzaywgSW5jMIGfMA0GCSqGSIb3DQEBAQUA
// SIG // A4GNADCBiQKBgQC1R1YKdvQF2Rj4+knWfj81afUtVyep
// SIG // GF2P4tcYD53qlYmYi9t9Csc6PMWlUZhMGbOceQKYcBjc
// SIG // mWvyghJnoaEQ6796ZcsLD0pMH2R4SpV/SjxiQ280beig
// SIG // NerJS5X+ftOMCs1qSQ1LXlRFEohaewkNWsIp/+f1Y0vE
// SIG // dGzggnEKOQIDAQABo4IBgzCCAX8wCQYDVR0TBAIwADAO
// SIG // BgNVHQ8BAf8EBAMCB4AwRAYDVR0fBD0wOzA5oDegNYYz
// SIG // aHR0cDovL2NzYzMtMjAwOS0yLWNybC52ZXJpc2lnbi5j
// SIG // b20vQ1NDMy0yMDA5LTIuY3JsMEQGA1UdIAQ9MDswOQYL
// SIG // YIZIAYb4RQEHFwMwKjAoBggrBgEFBQcCARYcaHR0cHM6
// SIG // Ly93d3cudmVyaXNpZ24uY29tL3JwYTATBgNVHSUEDDAK
// SIG // BggrBgEFBQcDAzB1BggrBgEFBQcBAQRpMGcwJAYIKwYB
// SIG // BQUHMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTA/
// SIG // BggrBgEFBQcwAoYzaHR0cDovL2NzYzMtMjAwOS0yLWFp
// SIG // YS52ZXJpc2lnbi5jb20vQ1NDMy0yMDA5LTIuY2VyMB8G
// SIG // A1UdIwQYMBaAFJfQa6gmcMihP5QfCC3ENZukoR7yMBEG
// SIG // CWCGSAGG+EIBAQQEAwIEEDAWBgorBgEEAYI3AgEbBAgw
// SIG // BgEBAAEB/zANBgkqhkiG9w0BAQUFAAOCAQEAIfxkh8Fd
// SIG // IHK+qtTf+9Eq5fjkk5gMMTQCOa+2aR7mqDzLfIFRGQzr
// SIG // tcc5/izsb/wPLUwdw1cRpnxO8/qLA2Ol+b99FONTOyyc
// SIG // Y8unwviYhdEjuFmqHkyC5MUYroZEjvTObFkkgN98Y48h
// SIG // C+mG2hdlVKXR0zr9r5q/rmmivVWbojvcYKHoW31O5OcM
// SIG // PsrWuOD305Ygmpck/91iopE3UN4tfeWYhzNj1F6Ai4Xa
// SIG // 5KiaMcs3zmoZ+6SePyI2YUgtff6yvy/rk8KVT41KGD2h
// SIG // fC+QrtVSkoDWP/MDtLjbTPCWElC1NWSEKowRI8t2x594
// SIG // Skjnzu/W5Lh97ixircOuM4IvBzGCAigwggIkAgEBMIHL
// SIG // MIG2MQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNp
// SIG // Z24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWduIFRydXN0
// SIG // IE5ldHdvcmsxOzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBh
// SIG // dCBodHRwczovL3d3dy52ZXJpc2lnbi5jb20vcnBhIChj
// SIG // KTA5MTAwLgYDVQQDEydWZXJpU2lnbiBDbGFzcyAzIENv
// SIG // ZGUgU2lnbmluZyAyMDA5LTIgQ0ECECNNoEvSQoU8Ssua
// SIG // 6GHCGbswDAYIKoZIhvcNAgUFAKCBsDAZBgkqhkiG9w0B
// SIG // CQMxDAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4w
// SIG // DAYKKwYBBAGCNwIBFTAfBgkqhkiG9w0BCQQxEgQQd3n3
// SIG // tM3ntf8tp+R/vwMQnDBUBgorBgEEAYI3AgEMMUYwRKAm
// SIG // gCQAQQB1AHQAbwBkAGUAcwBrACAAQwBvAG0AcABvAG4A
// SIG // ZQBuAHShGoAYaHR0cDovL3d3dy5hdXRvZGVzay5jb20g
// SIG // MA0GCSqGSIb3DQEBAQUABIGAqVGybpVCNLrfRVVurvn2
// SIG // etItVnfsLbckZE8Z1t1Y/dI6lYW8rkqO5Q/fx3PJMi7m
// SIG // Tb0YCrT9Bp2cuGyDIx643xdXyD1bdyLk/9BWK13WpjVi
// SIG // wC9JgknE2lL0bJZXqu4RPePuJ9cUan9MZ+5w1IxIwO34
// SIG // LXKoI+tdg+SSvyjm6dk=
// SIG // End signature block
