module("beehive.search.BeehiveSearchPanel")
.require("ui.Group",
         "ui.TextInput",
         "beehive.BeehiveService",
         "beehive.search.CategoryDropdown",
         "beehive.search.ResultItemRenderer",
         "ui.Button",
         "ui.ScrollGroup",
         "ui.List",
         "net.URI",
         "i18n.AutoLoad")
.declare("beehive.search.BeehiveSearchPanel").extend("ui.Group")
.as({
    widgetName:"beehiveSearchPanel",

    events:["ready","resultSelected"],

    options: {
        layoutOptions:{
            layout:"vertical",
            vlayout:"0:25px:25px 0:30px:30px 1",
            childSelector:".child"
        },
        view:"%modulePaths.beehiveViews%/BeehiveSearchPanelView.html",
        productInfo:{
            p:"",
            v:"",
            l:"",
            cg:"",
            c:""
        }
    },

    styles:["%modulePaths.beehiveStyles%/beehive-search-panel.css",
            "%modulePaths.beehiveStyles%/category-selector-theme.css",
            "%modulePaths.beehiveStyles%/results-scrollbar-theme.css"
            ],
    
    content:{
        "queryField":{
            type:"textInput",
            keydown:function(e){
                if(e.keyCode == $.ui.keyCode.ENTER){
                    this._onSubmitSearch();
                }
            }
        },
        "submit": {
            type:"button",
            options:{
                label:"{{str:SEARCH_BTN_LABEL|Search}}",
                text:false,
                icons:{
                    primary:"beehive-search-icon"
                }
            },
            click:function(){
                this._onSubmitSearch();
            }
        },
        "categorySelector":{
            type:"beehive.search.CategoryDropdown",
            options:{
                defaultHeaderData:"{{str:CHOOSE_OPTION|Choose an option...}}"
            },
            categoriesReady:function(){
                this.trigger("ready");
            },
            itemSelected:function(){
                    this._onSubmitSearch();
            }
        },
        "resultsPanel":{
            type:"scroll",
            options:{
                hideOnEmpty:"thumb"
            },
            content:{
                "results": {
                    type:"list",
                    options:{
                        itemRenderer:"beehive.search.ResultItemRenderer",
                        emptyMessage: "{{str:NO_RESULTS|No results found...}}"
                    },
                    itemSelected:function(e){
                        this.trigger({type:"resultSelected", resultItem:e.itemData});
                    },
                    itemRendered:function(e){
                        var resultsPanel = this.byId("resultsPanel");
                        resultsPanel.updateScroll();
                    }
                }
            }
        }
    },

    _init: function(){
        var self = this;
        this.base();
        this.byId("categorySelector").option("productInfo", this.options.productInfo);
        this.bind("ready", function(){
            self.byId("queryField").element.find("input").attr("tabindex","-1").focus();
        })
    },

    requestSearch: function(query){
        var input = this.byId("queryField");
        if(input){
            input.val(query);
        }
        this._onSubmitSearch();
    },

    _onSubmitSearch: function(){
        var self = this;
        var p = this.options.productInfo.p;
        var v = this.options.productInfo.v;
        var l = this.options.productInfo.l;
        var query = this.byId("queryField").val() || "";

        if(!query.trim()) return;

        var data = this.byId("categorySelector").selectedItemData();
        var cg = data.value.cg ||"";
        var c = data.value.c || "";
        var source = data.value.source || "all";
        var audience = data.value.audience || "";

        self._displayLoader(true);

        beehive.service.search2(p,v,l,query,cg,c,source,"upi",50,audience)
        .bind("ready",function(e){
            var resultsList = self.byId("results");
            var data = e.target.getData();
            if(data && data.entries && data.entries.item){
                resultsList.datasource(data.entries.item);
                resultsList.setSelectedItemFromIndex(0);

            }
            else{
                var uri = new net.URI(window.location.href);
                var suggestions = module.get("spelling.suggestion",data)||[];
                suggestions = suggestions.map(function(s){
                    uri.queryKey["query"]=s;
                    return module.tokenReplace('<a href="{{0}}">{{1}}</a>',
                                                [uri.toString(),s])

                });

                ui.Template.fromFile("%modulePaths.beehiveViews%/NoResultsView.html")
                .then(function(template){
                    var t = template.process({
                                             query:query,
                                             suggestions:suggestions.join(",")
                                            },self);

                    resultsList.option("emptyMessage",t);
                    resultsList.datasource([]);
                })
                .fail(function(e){
                    console.log(e);
                })
            }

            self._displayLoader(false);
        });
    },

    _displayLoader: function(display){
        this.element.find("#loader").css({display:display?"block":"none"})
    }
})
// SIG // Begin signature block
// SIG // MIIMzQYJKoZIhvcNAQcCoIIMvjCCDLoCAQExDjAMBggq
// SIG // hkiG9w0CBQUAMGYGCisGAQQBgjcCAQSgWDBWMDIGCisG
// SIG // AQQBgjcCAR4wJAIBAQQQEODJBs441BGiowAQS9NQkAIB
// SIG // AAIBAAIBAAIBAAIBADAgMAwGCCqGSIb3DQIFBQAEEH+Y
// SIG // nSGaWyF7VvBr6o0E6uygggoPMIIE/DCCBGWgAwIBAgIQ
// SIG // ZVIm4bIuGOFZDymFrCLnXDANBgkqhkiG9w0BAQUFADBf
// SIG // MQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24s
// SIG // IEluYy4xNzA1BgNVBAsTLkNsYXNzIDMgUHVibGljIFBy
// SIG // aW1hcnkgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkwHhcN
// SIG // MDkwNTIxMDAwMDAwWhcNMTkwNTIwMjM1OTU5WjCBtjEL
// SIG // MAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJ
// SIG // bmMuMR8wHQYDVQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3
// SIG // b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2UgYXQgaHR0
// SIG // cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykwOTEw
// SIG // MC4GA1UEAxMnVmVyaVNpZ24gQ2xhc3MgMyBDb2RlIFNp
// SIG // Z25pbmcgMjAwOS0yIENBMIIBIjANBgkqhkiG9w0BAQEF
// SIG // AAOCAQ8AMIIBCgKCAQEAvmcdtGCqEElvVhd8Zslehg3V
// SIG // 8ayncYOOi4n4iASJFQa6LYQhleTRnFBM+9IivdrysjU7
// SIG // Ho/DCfv8Ey5av4l8PTslHvbzWHuc9AG1xgq4gM6+J3Rh
// SIG // ZydNauXsgWFYeaPgFxASFSew4U00fytHIES53mYkZorN
// SIG // T7ofxTjIVJDhcvYZZnVquUlozzh5DaowqNssYEie16oU
// SIG // AamD1ziRMDkTlgM6fEBUtq3gLxuD3KgRUj4Cs9cr/SG2
// SIG // p1yjDwupphBQDjQuTafOyV4l1Iy88258KbwBXfwxh1rV
// SIG // jIVnWIgZoL818OoroyHnkPaD5ajtYHhee2CD/VcLXUEN
// SIG // Y1Rg1kMh7wIDAQABo4IB2zCCAdcwEgYDVR0TAQH/BAgw
// SIG // BgEB/wIBADBwBgNVHSAEaTBnMGUGC2CGSAGG+EUBBxcD
// SIG // MFYwKAYIKwYBBQUHAgEWHGh0dHBzOi8vd3d3LnZlcmlz
// SIG // aWduLmNvbS9jcHMwKgYIKwYBBQUHAgIwHhocaHR0cHM6
// SIG // Ly93d3cudmVyaXNpZ24uY29tL3JwYTAOBgNVHQ8BAf8E
// SIG // BAMCAQYwbQYIKwYBBQUHAQwEYTBfoV2gWzBZMFcwVRYJ
// SIG // aW1hZ2UvZ2lmMCEwHzAHBgUrDgMCGgQUj+XTGoasjY5r
// SIG // w8+AatRIGCx7GS4wJRYjaHR0cDovL2xvZ28udmVyaXNp
// SIG // Z24uY29tL3ZzbG9nby5naWYwHQYDVR0lBBYwFAYIKwYB
// SIG // BQUHAwIGCCsGAQUFBwMDMDQGCCsGAQUFBwEBBCgwJjAk
// SIG // BggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24u
// SIG // Y29tMDEGA1UdHwQqMCgwJqAkoCKGIGh0dHA6Ly9jcmwu
// SIG // dmVyaXNpZ24uY29tL3BjYTMuY3JsMCkGA1UdEQQiMCCk
// SIG // HjAcMRowGAYDVQQDExFDbGFzczNDQTIwNDgtMS01NTAd
// SIG // BgNVHQ4EFgQUl9BrqCZwyKE/lB8ILcQ1m6ShHvIwDQYJ
// SIG // KoZIhvcNAQEFBQADgYEAiwPA3ZTYQaJhabAVqHjHMMaQ
// SIG // PH5C9yS25INzFwR/BBCcoeL6gS/rwMpE53LgULZVECCD
// SIG // bpaS5JpRarQ3MdylLeuMAMcdT+dNMrqF+E6++mdVZfBq
// SIG // vnrKZDgaEBB4RXYx84Z6Aw9gwrNdnfaLZnaCG1nhg+W9
// SIG // SaU4VuXeQXcOWA8wggULMIID86ADAgECAhAjTaBL0kKF
// SIG // PErLmuhhwhm7MA0GCSqGSIb3DQEBBQUAMIG2MQswCQYD
// SIG // VQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4x
// SIG // HzAdBgNVBAsTFlZlcmlTaWduIFRydXN0IE5ldHdvcmsx
// SIG // OzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBhdCBodHRwczov
// SIG // L3d3dy52ZXJpc2lnbi5jb20vcnBhIChjKTA5MTAwLgYD
// SIG // VQQDEydWZXJpU2lnbiBDbGFzcyAzIENvZGUgU2lnbmlu
// SIG // ZyAyMDA5LTIgQ0EwHhcNMDkwODI3MDAwMDAwWhcNMTIw
// SIG // OTIwMjM1OTU5WjCByDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCkNhbGlmb3JuaWExEzARBgNVBAcTClNhbiBSYWZh
// SIG // ZWwxFjAUBgNVBAoUDUF1dG9kZXNrLCBJbmMxPjA8BgNV
// SIG // BAsTNURpZ2l0YWwgSUQgQ2xhc3MgMyAtIE1pY3Jvc29m
// SIG // dCBTb2Z0d2FyZSBWYWxpZGF0aW9uIHYyMR8wHQYDVQQL
// SIG // FBZEZXNpZ24gU29sdXRpb25zIEdyb3VwMRYwFAYDVQQD
// SIG // FA1BdXRvZGVzaywgSW5jMIGfMA0GCSqGSIb3DQEBAQUA
// SIG // A4GNADCBiQKBgQC1R1YKdvQF2Rj4+knWfj81afUtVyep
// SIG // GF2P4tcYD53qlYmYi9t9Csc6PMWlUZhMGbOceQKYcBjc
// SIG // mWvyghJnoaEQ6796ZcsLD0pMH2R4SpV/SjxiQ280beig
// SIG // NerJS5X+ftOMCs1qSQ1LXlRFEohaewkNWsIp/+f1Y0vE
// SIG // dGzggnEKOQIDAQABo4IBgzCCAX8wCQYDVR0TBAIwADAO
// SIG // BgNVHQ8BAf8EBAMCB4AwRAYDVR0fBD0wOzA5oDegNYYz
// SIG // aHR0cDovL2NzYzMtMjAwOS0yLWNybC52ZXJpc2lnbi5j
// SIG // b20vQ1NDMy0yMDA5LTIuY3JsMEQGA1UdIAQ9MDswOQYL
// SIG // YIZIAYb4RQEHFwMwKjAoBggrBgEFBQcCARYcaHR0cHM6
// SIG // Ly93d3cudmVyaXNpZ24uY29tL3JwYTATBgNVHSUEDDAK
// SIG // BggrBgEFBQcDAzB1BggrBgEFBQcBAQRpMGcwJAYIKwYB
// SIG // BQUHMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTA/
// SIG // BggrBgEFBQcwAoYzaHR0cDovL2NzYzMtMjAwOS0yLWFp
// SIG // YS52ZXJpc2lnbi5jb20vQ1NDMy0yMDA5LTIuY2VyMB8G
// SIG // A1UdIwQYMBaAFJfQa6gmcMihP5QfCC3ENZukoR7yMBEG
// SIG // CWCGSAGG+EIBAQQEAwIEEDAWBgorBgEEAYI3AgEbBAgw
// SIG // BgEBAAEB/zANBgkqhkiG9w0BAQUFAAOCAQEAIfxkh8Fd
// SIG // IHK+qtTf+9Eq5fjkk5gMMTQCOa+2aR7mqDzLfIFRGQzr
// SIG // tcc5/izsb/wPLUwdw1cRpnxO8/qLA2Ol+b99FONTOyyc
// SIG // Y8unwviYhdEjuFmqHkyC5MUYroZEjvTObFkkgN98Y48h
// SIG // C+mG2hdlVKXR0zr9r5q/rmmivVWbojvcYKHoW31O5OcM
// SIG // PsrWuOD305Ygmpck/91iopE3UN4tfeWYhzNj1F6Ai4Xa
// SIG // 5KiaMcs3zmoZ+6SePyI2YUgtff6yvy/rk8KVT41KGD2h
// SIG // fC+QrtVSkoDWP/MDtLjbTPCWElC1NWSEKowRI8t2x594
// SIG // Skjnzu/W5Lh97ixircOuM4IvBzGCAigwggIkAgEBMIHL
// SIG // MIG2MQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNp
// SIG // Z24sIEluYy4xHzAdBgNVBAsTFlZlcmlTaWduIFRydXN0
// SIG // IE5ldHdvcmsxOzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBh
// SIG // dCBodHRwczovL3d3dy52ZXJpc2lnbi5jb20vcnBhIChj
// SIG // KTA5MTAwLgYDVQQDEydWZXJpU2lnbiBDbGFzcyAzIENv
// SIG // ZGUgU2lnbmluZyAyMDA5LTIgQ0ECECNNoEvSQoU8Ssua
// SIG // 6GHCGbswDAYIKoZIhvcNAgUFAKCBsDAZBgkqhkiG9w0B
// SIG // CQMxDAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4w
// SIG // DAYKKwYBBAGCNwIBFTAfBgkqhkiG9w0BCQQxEgQQDHRy
// SIG // u9MnDSxjmxUtPwpqaDBUBgorBgEEAYI3AgEMMUYwRKAm
// SIG // gCQAQQB1AHQAbwBkAGUAcwBrACAAQwBvAG0AcABvAG4A
// SIG // ZQBuAHShGoAYaHR0cDovL3d3dy5hdXRvZGVzay5jb20g
// SIG // MA0GCSqGSIb3DQEBAQUABIGAZJQzFjeXe1xokLXVQeCP
// SIG // NCnpXvFCI2jYiMbIqUvD0cvJtmCBadLFfXYW1ZLAMHZj
// SIG // lJTI7LCMl88qtoubK2WS0O6Xo1riEKquFgAGLAFi01Be
// SIG // CUaeMyCSthfN3hjOywSae7xgJLoCEhTQVG1V1H0kwc5j
// SIG // M7X3M/qZoa1xbchalME=
// SIG // End signature block
